@@ -1,7 +1,7 @@
 package Text::Fragment;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2015-09-06'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -654,7 +654,7 @@ Text::Fragment - Manipulate fragments in text
 
 =head1 VERSION
 
-This document describes version 0.07 of Text::Fragment (from Perl distribution Text-Fragment), released on 2015-08-18.
+This document describes version 0.08 of Text::Fragment (from Perl distribution Text-Fragment), released on 2015-09-06.
 
 =head1 SYNOPSIS
 
@@ -716,7 +716,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Text-Fragm
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Text-Fragment>.
+Source repository is at L<https://github.com/sharyanto/perl-Text-Fragment>.
 
 =head1 BUGS
 
@@ -740,7 +740,6 @@ the same terms as the Perl 5 programming language system itself.
 =head1 DESCRIPTION
 
 
-{en_US 
 A fragment is a single line or a group of lines (called payload) with a metadata
 encoded in the comment that is put adjacent to it (for a single line fragment)
 or enclosing it (for a multiline fragment). Fragments are usually used in
@@ -794,23 +793,19 @@ Another example (using C<ini>-style comment):
  allow_url_fopen=0
  ; END FRAGMENT
 
-}
-
 =head1 FUNCTIONS
 
 
 =head2 delete_fragment(%args) -> [status, msg, result, meta]
 
-{en_US Delete fragment in text}.
+Delete fragment in text.
 
-{en_US 
 If there are multiple occurences of fragment (which is considered an abnormal
 condition), all occurences will be deleted.
 
 Newline deletion behaviour: if fragment at the bottom of text does not end with
 newline (which is considered bad style), the text after the fragment is deleted
 will also not end with newline.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -818,19 +813,19 @@ Arguments ('*' denotes required arguments):
 
 =item * B<comment_style> => I<str> (default: "shell")
 
-{en_US Comment style}.
+Comment style.
 
 =item * B<id>* => I<str>
 
-{en_US Fragment ID}.
+Fragment ID.
 
 =item * B<label> => I<str|code> (default: "FRAGMENT")
 
-{en_US Comment label}.
+Comment label.
 
 =item * B<text>* => I<str>
 
-{en_US The text to delete fragment from}.
+The text to delete fragment from.
 
 =back
 
@@ -843,10 +838,9 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Return value: {en_US A hash of result} (hash)
+Return value: A hash of result (hash)
 
 
-{en_US 
 Will return status 200 if operation is successful and text is deleted. The
 result is a hash with the following keys: C<text> will contain the new text,
 C<orig_payload> will contain the original fragment payload before being deleted,
@@ -856,16 +850,13 @@ fragment will be returned in C<orig_payload> and C<orig_fragment>.
 
 Will return status 304 if nothing is changed (i.e. when the fragment that needs
 to be deleted already does not exist in the text).
-}
 
 
 =head2 get_fragment(%args) -> [status, msg, result, meta]
 
-{en_US Get fragment with a certain ID in text}.
+Get fragment with a certain ID in text.
 
-{en_US 
 If there are multiple occurences of the fragment with the same ID ,
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -873,19 +864,19 @@ Arguments ('*' denotes required arguments):
 
 =item * B<comment_style> => I<str> (default: "shell")
 
-{en_US Comment style}.
+Comment style.
 
 =item * B<id>* => I<str>
 
-{en_US Fragment ID}.
+Fragment ID.
 
 =item * B<label> => I<str> (default: "FRAGMENT")
 
-{en_US Comment label}.
+Comment label.
 
 =item * B<text>* => I<str>
 
-{en_US The text which contain fragments}.
+The text which contain fragments.
 
 =back
 
@@ -898,28 +889,24 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Return value: {en_US Fragment} (array)
+Return value: Fragment (array)
 
 
-{en_US 
 Will return status 200 if fragment is found. Result will be a hash with the
 following keys: C<raw> (string), C<payload> (string), C<attrs> (hash), C<id>
 (string, can also be found in attributes).
 
 Return 404 if fragment is not found.
-}
 
 
 =head2 insert_fragment(%args) -> [status, msg, result, meta]
 
-{en_US Insert or replace a fragment in text}.
+Insert or replace a fragment in text.
 
-{en_US 
 Newline insertion behaviour: if fragment is inserted at the bottom and text does
 not end with newline (which is considered bad style), the inserted fragment will
 also not end with newline. Except when original text is an empty string, in
 which case an ending newline will still be added.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -929,50 +916,46 @@ Arguments ('*' denotes required arguments):
 
 =item * B<comment_style> => I<str> (default: "shell")
 
-{en_US Comment style}.
+Comment style.
 
 =item * B<good_pattern> => I<str>
 
-{en_US Regex pattern which if found means fragment need not be inserted}.
+Regex pattern which if found means fragment need not be inserted.
 
 =item * B<id>* => I<str>
 
-{en_US Fragment ID}.
+Fragment ID.
 
 =item * B<label> => I<str> (default: "FRAGMENT")
 
-{en_US Comment label}.
+Comment label.
 
 =item * B<payload>* => I<str>
 
-{en_US Fragment content}.
+Fragment content.
 
 =item * B<replace_pattern> => I<str>
 
-{en_US Regex pattern which if found will be used for placement of fragment}.
+Regex pattern which if found will be used for placement of fragment.
 
-{en_US 
 If fragment needs to be inserted into file, then if C<replace_pattern> is defined
 then it will be searched. If found, fragment will be placed to replace the
 pattern. Otherwise, fragment will be inserted at the end (or beginning, see
 C<top_style>) of file.
-}
 
 =item * B<text>* => I<str>
 
-{en_US The text to insert fragment into}.
+The text to insert fragment into.
 
 =item * B<top_style> => I<bool> (default: 0)
 
-{en_US Whether to append fragment at beginning of file instead of at the end}.
+Whether to append fragment at beginning of file instead of at the end.
 
-{en_US 
 Default is false, which means to append at the end of file.
 
 Note that this only has effect if C<replace_pattern> is not defined or replace
 pattern is not found in file. Otherwise, fragment will be inserted to replace
 the pattern.
-}
 
 =back
 
@@ -985,10 +968,9 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Return value: {en_US A hash of result} (hash)
+Return value: A hash of result (hash)
 
 
-{en_US 
 Will return status 200 if operation is successful and text is changed. The
 result is a hash with the following keys: C<text> will contain the new text,
 C<orig_payload> will contain the original payload before being removed/replaced,
@@ -997,12 +979,11 @@ C<replace_pattern>).
 
 Will return status 304 if nothing is changed (i.e. if fragment with the
 same payload that needs to be inserted already exists in the text).
-}
 
 
 =head2 list_fragments(%args) -> [status, msg, result, meta]
 
-{en_US List fragments in text}.
+List fragments in text.
 
 Arguments ('*' denotes required arguments):
 
@@ -1010,15 +991,15 @@ Arguments ('*' denotes required arguments):
 
 =item * B<comment_style> => I<str> (default: "shell")
 
-{en_US Comment style}.
+Comment style.
 
 =item * B<label> => I<str> (default: "FRAGMENT")
 
-{en_US Comment label}.
+Comment label.
 
 =item * B<text>* => I<str>
 
-{en_US The text which contain fragments}.
+The text which contain fragments.
 
 =back
 
@@ -1031,24 +1012,20 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Return value: {en_US List of fragments} (array)
+Return value: List of fragments (array)
 
 
-{en_US 
 Will return status 200 if operation is successful. Result will be an array of
 fragments, where each fragment is a hash containing these keys: C<raw> (string),
 C<payload> (string), C<attrs> (hash), C<id> (string, can also be found in
 attributes).
-}
 
 
 =head2 set_fragment_attrs(%args) -> [status, msg, result, meta]
 
-{en_US Set/unset attributes of a fragment}.
+Set/unset attributes of a fragment.
 
-{en_US 
 If there are multiple occurences of the fragment with the same ID ,
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -1056,25 +1033,23 @@ Arguments ('*' denotes required arguments):
 
 =item * B<attrs>* => I<hash>
 
-{en_US 
 To delete an attribute in the fragment, you can set the value to undef.
-}
 
 =item * B<comment_style> => I<str> (default: "shell")
 
-{en_US Comment style}.
+Comment style.
 
 =item * B<id>* => I<str>
 
-{en_US Fragment ID}.
+Fragment ID.
 
 =item * B<label> => I<str> (default: "FRAGMENT")
 
-{en_US Comment label}.
+Comment label.
 
 =item * B<text>* => I<str>
 
-{en_US The text which contain fragments}.
+The text which contain fragments.
 
 =back
 
@@ -1087,15 +1062,13 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Return value: {en_US New text and other data} (array)
+Return value: New text and other data (array)
 
 
-{en_US 
 Will return status 200 if fragment is found. Result will be a hash containing
 these keys: C<text> (string, the modified text), C<orig_attrs> (hash, the old
 attributes before being modified).
 
 Return 404 if fragment is not found.
-}
 
 =cut
